# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import Literal, overload

import httpx

from ..types import mobile_push_credential_list_params, mobile_push_credential_create_params
from .._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from .._utils import required_args, maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.push_credential_response import PushCredentialResponse
from ..types.mobile_push_credential_list_response import MobilePushCredentialListResponse

__all__ = ["MobilePushCredentialsResource", "AsyncMobilePushCredentialsResource"]


class MobilePushCredentialsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> MobilePushCredentialsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return MobilePushCredentialsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MobilePushCredentialsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return MobilePushCredentialsResourceWithStreamingResponse(self)

    @overload
    def create(
        self,
        *,
        alias: str,
        certificate: str,
        private_key: str,
        type: Literal["ios"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PushCredentialResponse:
        """
        Creates a new mobile push credential

        Args:
          alias: Alias to uniquely identify the credential

          certificate: Certificate as received from APNs

          private_key: Corresponding private key to the certificate as received from APNs

          type: Type of mobile push credential. Should be <code>ios</code> here

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        alias: str,
        project_account_json_file: Dict[str, object],
        type: Literal["android"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PushCredentialResponse:
        """
        Creates a new mobile push credential

        Args:
          alias: Alias to uniquely identify the credential

          project_account_json_file: Private key file in JSON format

          type: Type of mobile push credential. Should be <code>android</code> here

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(["alias", "certificate", "private_key", "type"], ["alias", "project_account_json_file", "type"])
    def create(
        self,
        *,
        alias: str,
        certificate: str | Omit = omit,
        private_key: str | Omit = omit,
        type: Literal["ios"] | Literal["android"],
        project_account_json_file: Dict[str, object] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PushCredentialResponse:
        return self._post(
            "/mobile_push_credentials",
            body=maybe_transform(
                {
                    "alias": alias,
                    "certificate": certificate,
                    "private_key": private_key,
                    "type": type,
                    "project_account_json_file": project_account_json_file,
                },
                mobile_push_credential_create_params.MobilePushCredentialCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PushCredentialResponse,
        )

    def retrieve(
        self,
        push_credential_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PushCredentialResponse:
        """
        Retrieves mobile push credential based on the given `push_credential_id`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not push_credential_id:
            raise ValueError(f"Expected a non-empty value for `push_credential_id` but received {push_credential_id!r}")
        return self._get(
            f"/mobile_push_credentials/{push_credential_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PushCredentialResponse,
        )

    def list(
        self,
        *,
        filter: mobile_push_credential_list_params.Filter | Omit = omit,
        page: mobile_push_credential_list_params.Page | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MobilePushCredentialListResponse:
        """
        List mobile push credentials

        Args:
          filter: Consolidated filter parameter (deepObject style). Originally: filter[type],
              filter[alias]

          page: Consolidated page parameter (deepObject style). Originally: page[size],
              page[number]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/mobile_push_credentials",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "page": page,
                    },
                    mobile_push_credential_list_params.MobilePushCredentialListParams,
                ),
            ),
            cast_to=MobilePushCredentialListResponse,
        )

    def delete(
        self,
        push_credential_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Deletes a mobile push credential based on the given `push_credential_id`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not push_credential_id:
            raise ValueError(f"Expected a non-empty value for `push_credential_id` but received {push_credential_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/mobile_push_credentials/{push_credential_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncMobilePushCredentialsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncMobilePushCredentialsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncMobilePushCredentialsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMobilePushCredentialsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncMobilePushCredentialsResourceWithStreamingResponse(self)

    @overload
    async def create(
        self,
        *,
        alias: str,
        certificate: str,
        private_key: str,
        type: Literal["ios"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PushCredentialResponse:
        """
        Creates a new mobile push credential

        Args:
          alias: Alias to uniquely identify the credential

          certificate: Certificate as received from APNs

          private_key: Corresponding private key to the certificate as received from APNs

          type: Type of mobile push credential. Should be <code>ios</code> here

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        alias: str,
        project_account_json_file: Dict[str, object],
        type: Literal["android"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PushCredentialResponse:
        """
        Creates a new mobile push credential

        Args:
          alias: Alias to uniquely identify the credential

          project_account_json_file: Private key file in JSON format

          type: Type of mobile push credential. Should be <code>android</code> here

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(["alias", "certificate", "private_key", "type"], ["alias", "project_account_json_file", "type"])
    async def create(
        self,
        *,
        alias: str,
        certificate: str | Omit = omit,
        private_key: str | Omit = omit,
        type: Literal["ios"] | Literal["android"],
        project_account_json_file: Dict[str, object] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PushCredentialResponse:
        return await self._post(
            "/mobile_push_credentials",
            body=await async_maybe_transform(
                {
                    "alias": alias,
                    "certificate": certificate,
                    "private_key": private_key,
                    "type": type,
                    "project_account_json_file": project_account_json_file,
                },
                mobile_push_credential_create_params.MobilePushCredentialCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PushCredentialResponse,
        )

    async def retrieve(
        self,
        push_credential_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PushCredentialResponse:
        """
        Retrieves mobile push credential based on the given `push_credential_id`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not push_credential_id:
            raise ValueError(f"Expected a non-empty value for `push_credential_id` but received {push_credential_id!r}")
        return await self._get(
            f"/mobile_push_credentials/{push_credential_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PushCredentialResponse,
        )

    async def list(
        self,
        *,
        filter: mobile_push_credential_list_params.Filter | Omit = omit,
        page: mobile_push_credential_list_params.Page | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MobilePushCredentialListResponse:
        """
        List mobile push credentials

        Args:
          filter: Consolidated filter parameter (deepObject style). Originally: filter[type],
              filter[alias]

          page: Consolidated page parameter (deepObject style). Originally: page[size],
              page[number]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/mobile_push_credentials",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "filter": filter,
                        "page": page,
                    },
                    mobile_push_credential_list_params.MobilePushCredentialListParams,
                ),
            ),
            cast_to=MobilePushCredentialListResponse,
        )

    async def delete(
        self,
        push_credential_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Deletes a mobile push credential based on the given `push_credential_id`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not push_credential_id:
            raise ValueError(f"Expected a non-empty value for `push_credential_id` but received {push_credential_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/mobile_push_credentials/{push_credential_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class MobilePushCredentialsResourceWithRawResponse:
    def __init__(self, mobile_push_credentials: MobilePushCredentialsResource) -> None:
        self._mobile_push_credentials = mobile_push_credentials

        self.create = to_raw_response_wrapper(
            mobile_push_credentials.create,
        )
        self.retrieve = to_raw_response_wrapper(
            mobile_push_credentials.retrieve,
        )
        self.list = to_raw_response_wrapper(
            mobile_push_credentials.list,
        )
        self.delete = to_raw_response_wrapper(
            mobile_push_credentials.delete,
        )


class AsyncMobilePushCredentialsResourceWithRawResponse:
    def __init__(self, mobile_push_credentials: AsyncMobilePushCredentialsResource) -> None:
        self._mobile_push_credentials = mobile_push_credentials

        self.create = async_to_raw_response_wrapper(
            mobile_push_credentials.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            mobile_push_credentials.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            mobile_push_credentials.list,
        )
        self.delete = async_to_raw_response_wrapper(
            mobile_push_credentials.delete,
        )


class MobilePushCredentialsResourceWithStreamingResponse:
    def __init__(self, mobile_push_credentials: MobilePushCredentialsResource) -> None:
        self._mobile_push_credentials = mobile_push_credentials

        self.create = to_streamed_response_wrapper(
            mobile_push_credentials.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            mobile_push_credentials.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            mobile_push_credentials.list,
        )
        self.delete = to_streamed_response_wrapper(
            mobile_push_credentials.delete,
        )


class AsyncMobilePushCredentialsResourceWithStreamingResponse:
    def __init__(self, mobile_push_credentials: AsyncMobilePushCredentialsResource) -> None:
        self._mobile_push_credentials = mobile_push_credentials

        self.create = async_to_streamed_response_wrapper(
            mobile_push_credentials.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            mobile_push_credentials.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            mobile_push_credentials.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            mobile_push_credentials.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union
from typing_extensions import TypeAlias

__all__ = ["EnumRetrieveResponse"]

EnumRetrieveResponse: TypeAlias = Union[List[Union[str, object]], object, object]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["VerifiedNumberListParams", "Page"]


class VerifiedNumberListParams(TypedDict, total=False):
    page: Page
    """Consolidated page parameter (deepObject style).

    Use page[size] and page[number] in the query string. Originally: page[size],
    page[number]
    """


class Page(TypedDict, total=False):
    number: int

    size: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel

__all__ = ["NumbersFeatureCreateResponse", "Data"]


class Data(BaseModel):
    features: List[str]

    phone_number: str


class NumbersFeatureCreateResponse(BaseModel):
    data: Optional[List[Data]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from .meta import Meta
from ......_models import BaseModel
from ..test_run_response import TestRunResponse

__all__ = ["PaginatedTestRunList"]


class PaginatedTestRunList(BaseModel):
    data: List[TestRunResponse]
    """Array of test run objects for the current page."""

    meta: Meta
    """Pagination metadata including total counts and current page info."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["CampaignSharingStatus"]


class CampaignSharingStatus(BaseModel):
    downstream_cnp_id: Optional[str] = FieldInfo(alias="downstreamCnpId", default=None)

    shared_date: Optional[str] = FieldInfo(alias="sharedDate", default=None)

    sharing_status: Optional[str] = FieldInfo(alias="sharingStatus", default=None)

    status_date: Optional[str] = FieldInfo(alias="statusDate", default=None)

    upstream_cnp_id: Optional[str] = FieldInfo(alias="upstreamCnpId", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["VoiceListParams", "Filter", "FilterConnectionName", "Page"]


class VoiceListParams(TypedDict, total=False):
    filter: Filter
    """Consolidated filter parameter (deepObject style).

    Originally: filter[phone_number], filter[connection_name],
    filter[customer_reference], filter[voice.usage_payment_method]
    """

    page: Page
    """Consolidated page parameter (deepObject style).

    Originally: page[size], page[number]
    """

    sort: Literal["purchased_at", "phone_number", "connection_name", "usage_payment_method"]
    """Specifies the sort order for results.

    If not given, results are sorted by created_at in descending order.
    """


class FilterConnectionName(TypedDict, total=False):
    contains: str
    """Filter contains connection name. Requires at least three characters."""


class Filter(TypedDict, total=False):
    connection_name: FilterConnectionName
    """Filter by connection name pattern matching."""

    customer_reference: str
    """Filter numbers via the customer_reference set."""

    phone_number: str
    """Filter by phone number.

    Requires at least three digits. Non-numerical characters will result in no
    values being returned.
    """

    voice_usage_payment_method: Annotated[
        Literal["pay-per-minute", "channel"], PropertyInfo(alias="voice.usage_payment_method")
    ]
    """Filter by usage_payment_method."""


class Page(TypedDict, total=False):
    number: int
    """The page number to load"""

    size: int
    """The size of the page"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["ActionListParams", "Filter", "Page"]


class ActionListParams(TypedDict, total=False):
    filter: Filter
    """Consolidated filter parameter for SIM card actions (deepObject style).

    Originally: filter[sim_card_id], filter[status],
    filter[bulk_sim_card_action_id], filter[action_type]
    """

    page: Page
    """Consolidated pagination parameter (deepObject style).

    Originally: page[number], page[size]
    """


class Filter(TypedDict, total=False):
    action_type: Literal[
        "enable", "enable_standby_sim_card", "disable", "set_standby", "remove_public_ip", "set_public_ip"
    ]
    """Filter by action type."""

    bulk_sim_card_action_id: str
    """Filter by a bulk SIM card action ID."""

    sim_card_id: str
    """A valid SIM card ID."""

    status: Literal["in-progress", "completed", "failed"]
    """Filter by a specific status of the resource's lifecycle."""


class Page(TypedDict, total=False):
    number: int
    """The page number to load."""

    size: int
    """The size of the page."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo
from .vertical import Vertical
from .entity_type import EntityType
from .stock_exchange import StockExchange
from .alt_business_id_type import AltBusinessIDType
from .brand_identity_status import BrandIdentityStatus

__all__ = ["BrandUpdateParams"]


class BrandUpdateParams(TypedDict, total=False):
    country: Required[str]
    """ISO2 2 characters country code. Example: US - United States"""

    display_name: Required[Annotated[str, PropertyInfo(alias="displayName")]]
    """Display or marketing name of the brand."""

    email: Required[str]
    """Valid email address of brand support contact."""

    entity_type: Required[Annotated[EntityType, PropertyInfo(alias="entityType")]]
    """Entity type behind the brand. This is the form of business establishment."""

    vertical: Required[Vertical]
    """Vertical or industry segment of the brand or campaign."""

    alt_business_id: Annotated[str, PropertyInfo(alias="altBusiness_id")]
    """Alternate business identifier such as DUNS, LEI, or GIIN"""

    alt_business_id_type: Annotated[AltBusinessIDType, PropertyInfo(alias="altBusinessIdType")]
    """An enumeration."""

    business_contact_email: Annotated[str, PropertyInfo(alias="businessContactEmail")]
    """Business contact email.

    Required if `entityType` will be changed to `PUBLIC_PROFIT`. Otherwise, it is
    recommended to either omit this field or set it to `null`.
    """

    city: str
    """City name"""

    company_name: Annotated[str, PropertyInfo(alias="companyName")]
    """(Required for Non-profit/private/public) Legal company name."""

    ein: str
    """(Required for Non-profit) Government assigned corporate tax ID.

    EIN is 9-digits in U.S.
    """

    first_name: Annotated[str, PropertyInfo(alias="firstName")]
    """First name of business contact."""

    identity_status: Annotated[BrandIdentityStatus, PropertyInfo(alias="identityStatus")]
    """The verification status of an active brand"""

    ip_address: Annotated[str, PropertyInfo(alias="ipAddress")]
    """IP address of the browser requesting to create brand identity."""

    is_reseller: Annotated[bool, PropertyInfo(alias="isReseller")]

    last_name: Annotated[str, PropertyInfo(alias="lastName")]
    """Last name of business contact."""

    phone: str
    """Valid phone number in e.164 international format."""

    postal_code: Annotated[str, PropertyInfo(alias="postalCode")]
    """Postal codes. Use 5 digit zipcode for United States"""

    state: str
    """State. Must be 2 letters code for United States."""

    stock_exchange: Annotated[StockExchange, PropertyInfo(alias="stockExchange")]
    """(Required for public company) stock exchange."""

    stock_symbol: Annotated[str, PropertyInfo(alias="stockSymbol")]
    """(Required for public company) stock symbol."""

    street: str
    """Street number and name."""

    webhook_failover_url: Annotated[str, PropertyInfo(alias="webhookFailoverURL")]
    """Webhook failover URL for brand status updates."""

    webhook_url: Annotated[str, PropertyInfo(alias="webhookURL")]
    """Webhook URL for brand status updates."""

    website: str
    """Brand website URL."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel
from .portout_details import PortoutDetails
from .shared.metadata import Metadata

__all__ = ["PortoutListResponse"]


class PortoutListResponse(BaseModel):
    data: Optional[List[PortoutDetails]] = None

    meta: Optional[Metadata] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .voice_list_params import VoiceListParams as VoiceListParams
from .voice_create_params import VoiceCreateParams as VoiceCreateParams
from .voice_list_response import VoiceListResponse as VoiceListResponse
from .messaging_list_params import MessagingListParams as MessagingListParams
from .voice_create_response import VoiceCreateResponse as VoiceCreateResponse
from .voice_delete_response import VoiceDeleteResponse as VoiceDeleteResponse
from .messaging_create_params import MessagingCreateParams as MessagingCreateParams
from .messaging_list_response import MessagingListResponse as MessagingListResponse
from .voice_retrieve_response import VoiceRetrieveResponse as VoiceRetrieveResponse
from .standard_pagination_meta import StandardPaginationMeta as StandardPaginationMeta
from .messaging_create_response import MessagingCreateResponse as MessagingCreateResponse
from .messaging_delete_response import MessagingDeleteResponse as MessagingDeleteResponse
from .number_lookup_list_params import NumberLookupListParams as NumberLookupListParams
from .messaging_retrieve_response import MessagingRetrieveResponse as MessagingRetrieveResponse
from .number_lookup_create_params import NumberLookupCreateParams as NumberLookupCreateParams
from .cdr_usage_report_response_legacy import CdrUsageReportResponseLegacy as CdrUsageReportResponseLegacy
from .mdr_usage_report_response_legacy import MdrUsageReportResponseLegacy as MdrUsageReportResponseLegacy



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.wireless import detail_records_report_list_params, detail_records_report_create_params
from ...types.wireless.detail_records_report_list_response import DetailRecordsReportListResponse
from ...types.wireless.detail_records_report_create_response import DetailRecordsReportCreateResponse
from ...types.wireless.detail_records_report_delete_response import DetailRecordsReportDeleteResponse
from ...types.wireless.detail_records_report_retrieve_response import DetailRecordsReportRetrieveResponse

__all__ = ["DetailRecordsReportsResource", "AsyncDetailRecordsReportsResource"]


class DetailRecordsReportsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> DetailRecordsReportsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return DetailRecordsReportsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> DetailRecordsReportsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return DetailRecordsReportsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        end_time: str | Omit = omit,
        start_time: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DetailRecordsReportCreateResponse:
        """
        Asynchronously create a report containing Wireless Detail Records (WDRs) for the
        SIM cards that consumed wireless data in the given time period.

        Args:
          end_time: ISO 8601 formatted date-time indicating the end time.

          start_time: ISO 8601 formatted date-time indicating the start time.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/wireless/detail_records_reports",
            body=maybe_transform(
                {
                    "end_time": end_time,
                    "start_time": start_time,
                },
                detail_records_report_create_params.DetailRecordsReportCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DetailRecordsReportCreateResponse,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DetailRecordsReportRetrieveResponse:
        """
        Returns one specific WDR report

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/wireless/detail_records_reports/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DetailRecordsReportRetrieveResponse,
        )

    def list(
        self,
        *,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DetailRecordsReportListResponse:
        """
        Returns the WDR Reports that match the given parameters.

        Args:
          page_number: The page number to load.

          page_size: The size of the page.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/wireless/detail_records_reports",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "page_number": page_number,
                        "page_size": page_size,
                    },
                    detail_records_report_list_params.DetailRecordsReportListParams,
                ),
            ),
            cast_to=DetailRecordsReportListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DetailRecordsReportDeleteResponse:
        """
        Deletes one specific WDR report.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._delete(
            f"/wireless/detail_records_reports/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DetailRecordsReportDeleteResponse,
        )


class AsyncDetailRecordsReportsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncDetailRecordsReportsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncDetailRecordsReportsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncDetailRecordsReportsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncDetailRecordsReportsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        end_time: str | Omit = omit,
        start_time: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DetailRecordsReportCreateResponse:
        """
        Asynchronously create a report containing Wireless Detail Records (WDRs) for the
        SIM cards that consumed wireless data in the given time period.

        Args:
          end_time: ISO 8601 formatted date-time indicating the end time.

          start_time: ISO 8601 formatted date-time indicating the start time.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/wireless/detail_records_reports",
            body=await async_maybe_transform(
                {
                    "end_time": end_time,
                    "start_time": start_time,
                },
                detail_records_report_create_params.DetailRecordsReportCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DetailRecordsReportCreateResponse,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DetailRecordsReportRetrieveResponse:
        """
        Returns one specific WDR report

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/wireless/detail_records_reports/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DetailRecordsReportRetrieveResponse,
        )

    async def list(
        self,
        *,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DetailRecordsReportListResponse:
        """
        Returns the WDR Reports that match the given parameters.

        Args:
          page_number: The page number to load.

          page_size: The size of the page.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/wireless/detail_records_reports",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "page_number": page_number,
                        "page_size": page_size,
                    },
                    detail_records_report_list_params.DetailRecordsReportListParams,
                ),
            ),
            cast_to=DetailRecordsReportListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DetailRecordsReportDeleteResponse:
        """
        Deletes one specific WDR report.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._delete(
            f"/wireless/detail_records_reports/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DetailRecordsReportDeleteResponse,
        )


class DetailRecordsReportsResourceWithRawResponse:
    def __init__(self, detail_records_reports: DetailRecordsReportsResource) -> None:
        self._detail_records_reports = detail_records_reports

        self.create = to_raw_response_wrapper(
            detail_records_reports.create,
        )
        self.retrieve = to_raw_response_wrapper(
            detail_records_reports.retrieve,
        )
        self.list = to_raw_response_wrapper(
            detail_records_reports.list,
        )
        self.delete = to_raw_response_wrapper(
            detail_records_reports.delete,
        )


class AsyncDetailRecordsReportsResourceWithRawResponse:
    def __init__(self, detail_records_reports: AsyncDetailRecordsReportsResource) -> None:
        self._detail_records_reports = detail_records_reports

        self.create = async_to_raw_response_wrapper(
            detail_records_reports.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            detail_records_reports.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            detail_records_reports.list,
        )
        self.delete = async_to_raw_response_wrapper(
            detail_records_reports.delete,
        )


class DetailRecordsReportsResourceWithStreamingResponse:
    def __init__(self, detail_records_reports: DetailRecordsReportsResource) -> None:
        self._detail_records_reports = detail_records_reports

        self.create = to_streamed_response_wrapper(
            detail_records_reports.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            detail_records_reports.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            detail_records_reports.list,
        )
        self.delete = to_streamed_response_wrapper(
            detail_records_reports.delete,
        )


class AsyncDetailRecordsReportsResourceWithStreamingResponse:
    def __init__(self, detail_records_reports: AsyncDetailRecordsReportsResource) -> None:
        self._detail_records_reports = detail_records_reports

        self.create = async_to_streamed_response_wrapper(
            detail_records_reports.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            detail_records_reports.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            detail_records_reports.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            detail_records_reports.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import httpx
import pytest
from respx import MockRouter

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.types import (
    DocumentListResponse,
    DocumentDeleteResponse,
    DocumentUpdateResponse,
    DocumentUploadResponse,
    DocumentRetrieveResponse,
    DocumentUploadJsonResponse,
    DocumentGenerateDownloadLinkResponse,
)
from telnyx._utils import parse_datetime
from telnyx._response import (
    BinaryAPIResponse,
    AsyncBinaryAPIResponse,
    StreamedBinaryAPIResponse,
    AsyncStreamedBinaryAPIResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestDocuments:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Telnyx) -> None:
        document = client.documents.retrieve(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert_matches_type(DocumentRetrieveResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Telnyx) -> None:
        response = client.documents.with_raw_response.retrieve(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = response.parse()
        assert_matches_type(DocumentRetrieveResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Telnyx) -> None:
        with client.documents.with_streaming_response.retrieve(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = response.parse()
            assert_matches_type(DocumentRetrieveResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.documents.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update(self, client: Telnyx) -> None:
        document = client.documents.update(
            id="6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert_matches_type(DocumentUpdateResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: Telnyx) -> None:
        document = client.documents.update(
            id="6a09cdc3-8948-47f0-aa62-74ac943d6c58",
            customer_reference="MY REF 001",
            filename="test-document.pdf",
        )
        assert_matches_type(DocumentUpdateResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: Telnyx) -> None:
        response = client.documents.with_raw_response.update(
            id="6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = response.parse()
        assert_matches_type(DocumentUpdateResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: Telnyx) -> None:
        with client.documents.with_streaming_response.update(
            id="6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = response.parse()
            assert_matches_type(DocumentUpdateResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_update(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.documents.with_raw_response.update(
                id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Telnyx) -> None:
        document = client.documents.list()
        assert_matches_type(DocumentListResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Telnyx) -> None:
        document = client.documents.list(
            filter={
                "created_at": {
                    "gt": parse_datetime("2021-01-01T00:00:00Z"),
                    "lt": parse_datetime("2021-04-09T22:25:27.521Z"),
                },
                "customer_reference": {
                    "eq": "MY REF 001",
                    "in": ["REF001", "REF002"],
                },
                "filename": {"contains": "invoice"},
            },
            page={
                "number": 1,
                "size": 1,
            },
            sort=["filename"],
        )
        assert_matches_type(DocumentListResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Telnyx) -> None:
        response = client.documents.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = response.parse()
        assert_matches_type(DocumentListResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Telnyx) -> None:
        with client.documents.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = response.parse()
            assert_matches_type(DocumentListResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete(self, client: Telnyx) -> None:
        document = client.documents.delete(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert_matches_type(DocumentDeleteResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: Telnyx) -> None:
        response = client.documents.with_raw_response.delete(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = response.parse()
        assert_matches_type(DocumentDeleteResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: Telnyx) -> None:
        with client.documents.with_streaming_response.delete(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = response.parse()
            assert_matches_type(DocumentDeleteResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.documents.with_raw_response.delete(
                "",
            )

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_method_download(self, client: Telnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/documents/6a09cdc3-8948-47f0-aa62-74ac943d6c58/download").mock(
            return_value=httpx.Response(200, json={"foo": "bar"})
        )
        document = client.documents.download(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert document.is_closed
        assert document.json() == {"foo": "bar"}
        assert cast(Any, document.is_closed) is True
        assert isinstance(document, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_raw_response_download(self, client: Telnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/documents/6a09cdc3-8948-47f0-aa62-74ac943d6c58/download").mock(
            return_value=httpx.Response(200, json={"foo": "bar"})
        )

        document = client.documents.with_raw_response.download(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert document.is_closed is True
        assert document.http_request.headers.get("X-Stainless-Lang") == "python"
        assert document.json() == {"foo": "bar"}
        assert isinstance(document, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_streaming_response_download(self, client: Telnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/documents/6a09cdc3-8948-47f0-aa62-74ac943d6c58/download").mock(
            return_value=httpx.Response(200, json={"foo": "bar"})
        )
        with client.documents.with_streaming_response.download(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as document:
            assert not document.is_closed
            assert document.http_request.headers.get("X-Stainless-Lang") == "python"

            assert document.json() == {"foo": "bar"}
            assert cast(Any, document.is_closed) is True
            assert isinstance(document, StreamedBinaryAPIResponse)

        assert cast(Any, document.is_closed) is True

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_path_params_download(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.documents.with_raw_response.download(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_generate_download_link(self, client: Telnyx) -> None:
        document = client.documents.generate_download_link(
            "550e8400-e29b-41d4-a716-446655440000",
        )
        assert_matches_type(DocumentGenerateDownloadLinkResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_generate_download_link(self, client: Telnyx) -> None:
        response = client.documents.with_raw_response.generate_download_link(
            "550e8400-e29b-41d4-a716-446655440000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = response.parse()
        assert_matches_type(DocumentGenerateDownloadLinkResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_generate_download_link(self, client: Telnyx) -> None:
        with client.documents.with_streaming_response.generate_download_link(
            "550e8400-e29b-41d4-a716-446655440000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = response.parse()
            assert_matches_type(DocumentGenerateDownloadLinkResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_generate_download_link(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.documents.with_raw_response.generate_download_link(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_upload_overload_1(self, client: Telnyx) -> None:
        document = client.documents.upload(
            url="https://www.w3.org/WAI/ER/tests/xhtml/testfiles/resources/pdf/dummy.pdf",
        )
        assert_matches_type(DocumentUploadResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_upload_with_all_params_overload_1(self, client: Telnyx) -> None:
        document = client.documents.upload(
            url="https://www.w3.org/WAI/ER/tests/xhtml/testfiles/resources/pdf/dummy.pdf",
            customer_reference="MY REF 001",
            filename="test-document.pdf",
        )
        assert_matches_type(DocumentUploadResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_upload_overload_1(self, client: Telnyx) -> None:
        response = client.documents.with_raw_response.upload(
            url="https://www.w3.org/WAI/ER/tests/xhtml/testfiles/resources/pdf/dummy.pdf",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = response.parse()
        assert_matches_type(DocumentUploadResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_upload_overload_1(self, client: Telnyx) -> None:
        with client.documents.with_streaming_response.upload(
            url="https://www.w3.org/WAI/ER/tests/xhtml/testfiles/resources/pdf/dummy.pdf",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = response.parse()
            assert_matches_type(DocumentUploadResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_upload_overload_2(self, client: Telnyx) -> None:
        document = client.documents.upload(
            file="U3RhaW5sZXNzIHJvY2tz",
        )
        assert_matches_type(DocumentUploadResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_upload_with_all_params_overload_2(self, client: Telnyx) -> None:
        document = client.documents.upload(
            file="U3RhaW5sZXNzIHJvY2tz",
            customer_reference="MY REF 001",
            filename="test-document.pdf",
        )
        assert_matches_type(DocumentUploadResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_upload_overload_2(self, client: Telnyx) -> None:
        response = client.documents.with_raw_response.upload(
            file="U3RhaW5sZXNzIHJvY2tz",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = response.parse()
        assert_matches_type(DocumentUploadResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_upload_overload_2(self, client: Telnyx) -> None:
        with client.documents.with_streaming_response.upload(
            file="U3RhaW5sZXNzIHJvY2tz",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = response.parse()
            assert_matches_type(DocumentUploadResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_upload_json_overload_1(self, client: Telnyx) -> None:
        document = client.documents.upload_json(
            url="https://www.w3.org/WAI/ER/tests/xhtml/testfiles/resources/pdf/dummy.pdf",
        )
        assert_matches_type(DocumentUploadJsonResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_upload_json_with_all_params_overload_1(self, client: Telnyx) -> None:
        document = client.documents.upload_json(
            url="https://www.w3.org/WAI/ER/tests/xhtml/testfiles/resources/pdf/dummy.pdf",
            customer_reference="MY REF 001",
            filename="test-document.pdf",
        )
        assert_matches_type(DocumentUploadJsonResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_upload_json_overload_1(self, client: Telnyx) -> None:
        response = client.documents.with_raw_response.upload_json(
            url="https://www.w3.org/WAI/ER/tests/xhtml/testfiles/resources/pdf/dummy.pdf",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = response.parse()
        assert_matches_type(DocumentUploadJsonResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_upload_json_overload_1(self, client: Telnyx) -> None:
        with client.documents.with_streaming_response.upload_json(
            url="https://www.w3.org/WAI/ER/tests/xhtml/testfiles/resources/pdf/dummy.pdf",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = response.parse()
            assert_matches_type(DocumentUploadJsonResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_upload_json_overload_2(self, client: Telnyx) -> None:
        document = client.documents.upload_json(
            file="U3RhaW5sZXNzIHJvY2tz",
        )
        assert_matches_type(DocumentUploadJsonResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_upload_json_with_all_params_overload_2(self, client: Telnyx) -> None:
        document = client.documents.upload_json(
            file="U3RhaW5sZXNzIHJvY2tz",
            customer_reference="MY REF 001",
            filename="test-document.pdf",
        )
        assert_matches_type(DocumentUploadJsonResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_upload_json_overload_2(self, client: Telnyx) -> None:
        response = client.documents.with_raw_response.upload_json(
            file="U3RhaW5sZXNzIHJvY2tz",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = response.parse()
        assert_matches_type(DocumentUploadJsonResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_upload_json_overload_2(self, client: Telnyx) -> None:
        with client.documents.with_streaming_response.upload_json(
            file="U3RhaW5sZXNzIHJvY2tz",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = response.parse()
            assert_matches_type(DocumentUploadJsonResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncDocuments:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncTelnyx) -> None:
        document = await async_client.documents.retrieve(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert_matches_type(DocumentRetrieveResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.documents.with_raw_response.retrieve(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = await response.parse()
        assert_matches_type(DocumentRetrieveResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        async with async_client.documents.with_streaming_response.retrieve(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = await response.parse()
            assert_matches_type(DocumentRetrieveResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.documents.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncTelnyx) -> None:
        document = await async_client.documents.update(
            id="6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert_matches_type(DocumentUpdateResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncTelnyx) -> None:
        document = await async_client.documents.update(
            id="6a09cdc3-8948-47f0-aa62-74ac943d6c58",
            customer_reference="MY REF 001",
            filename="test-document.pdf",
        )
        assert_matches_type(DocumentUpdateResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.documents.with_raw_response.update(
            id="6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = await response.parse()
        assert_matches_type(DocumentUpdateResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncTelnyx) -> None:
        async with async_client.documents.with_streaming_response.update(
            id="6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = await response.parse()
            assert_matches_type(DocumentUpdateResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.documents.with_raw_response.update(
                id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncTelnyx) -> None:
        document = await async_client.documents.list()
        assert_matches_type(DocumentListResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncTelnyx) -> None:
        document = await async_client.documents.list(
            filter={
                "created_at": {
                    "gt": parse_datetime("2021-01-01T00:00:00Z"),
                    "lt": parse_datetime("2021-04-09T22:25:27.521Z"),
                },
                "customer_reference": {
                    "eq": "MY REF 001",
                    "in": ["REF001", "REF002"],
                },
                "filename": {"contains": "invoice"},
            },
            page={
                "number": 1,
                "size": 1,
            },
            sort=["filename"],
        )
        assert_matches_type(DocumentListResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.documents.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = await response.parse()
        assert_matches_type(DocumentListResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncTelnyx) -> None:
        async with async_client.documents.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = await response.parse()
            assert_matches_type(DocumentListResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncTelnyx) -> None:
        document = await async_client.documents.delete(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert_matches_type(DocumentDeleteResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.documents.with_raw_response.delete(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = await response.parse()
        assert_matches_type(DocumentDeleteResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncTelnyx) -> None:
        async with async_client.documents.with_streaming_response.delete(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = await response.parse()
            assert_matches_type(DocumentDeleteResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.documents.with_raw_response.delete(
                "",
            )

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_method_download(self, async_client: AsyncTelnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/documents/6a09cdc3-8948-47f0-aa62-74ac943d6c58/download").mock(
            return_value=httpx.Response(200, json={"foo": "bar"})
        )
        document = await async_client.documents.download(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )
        assert document.is_closed
        assert await document.json() == {"foo": "bar"}
        assert cast(Any, document.is_closed) is True
        assert isinstance(document, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_raw_response_download(self, async_client: AsyncTelnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/documents/6a09cdc3-8948-47f0-aa62-74ac943d6c58/download").mock(
            return_value=httpx.Response(200, json={"foo": "bar"})
        )

        document = await async_client.documents.with_raw_response.download(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        )

        assert document.is_closed is True
        assert document.http_request.headers.get("X-Stainless-Lang") == "python"
        assert await document.json() == {"foo": "bar"}
        assert isinstance(document, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_streaming_response_download(self, async_client: AsyncTelnyx, respx_mock: MockRouter) -> None:
        respx_mock.get("/documents/6a09cdc3-8948-47f0-aa62-74ac943d6c58/download").mock(
            return_value=httpx.Response(200, json={"foo": "bar"})
        )
        async with async_client.documents.with_streaming_response.download(
            "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
        ) as document:
            assert not document.is_closed
            assert document.http_request.headers.get("X-Stainless-Lang") == "python"

            assert await document.json() == {"foo": "bar"}
            assert cast(Any, document.is_closed) is True
            assert isinstance(document, AsyncStreamedBinaryAPIResponse)

        assert cast(Any, document.is_closed) is True

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_path_params_download(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.documents.with_raw_response.download(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_generate_download_link(self, async_client: AsyncTelnyx) -> None:
        document = await async_client.documents.generate_download_link(
            "550e8400-e29b-41d4-a716-446655440000",
        )
        assert_matches_type(DocumentGenerateDownloadLinkResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_generate_download_link(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.documents.with_raw_response.generate_download_link(
            "550e8400-e29b-41d4-a716-446655440000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = await response.parse()
        assert_matches_type(DocumentGenerateDownloadLinkResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_generate_download_link(self, async_client: AsyncTelnyx) -> None:
        async with async_client.documents.with_streaming_response.generate_download_link(
            "550e8400-e29b-41d4-a716-446655440000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = await response.parse()
            assert_matches_type(DocumentGenerateDownloadLinkResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_generate_download_link(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.documents.with_raw_response.generate_download_link(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_upload_overload_1(self, async_client: AsyncTelnyx) -> None:
        document = await async_client.documents.upload(
            url="https://www.w3.org/WAI/ER/tests/xhtml/testfiles/resources/pdf/dummy.pdf",
        )
        assert_matches_type(DocumentUploadResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_upload_with_all_params_overload_1(self, async_client: AsyncTelnyx) -> None:
        document = await async_client.documents.upload(
            url="https://www.w3.org/WAI/ER/tests/xhtml/testfiles/resources/pdf/dummy.pdf",
            customer_reference="MY REF 001",
            filename="test-document.pdf",
        )
        assert_matches_type(DocumentUploadResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_upload_overload_1(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.documents.with_raw_response.upload(
            url="https://www.w3.org/WAI/ER/tests/xhtml/testfiles/resources/pdf/dummy.pdf",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = await response.parse()
        assert_matches_type(DocumentUploadResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_upload_overload_1(self, async_client: AsyncTelnyx) -> None:
        async with async_client.documents.with_streaming_response.upload(
            url="https://www.w3.org/WAI/ER/tests/xhtml/testfiles/resources/pdf/dummy.pdf",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = await response.parse()
            assert_matches_type(DocumentUploadResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_upload_overload_2(self, async_client: AsyncTelnyx) -> None:
        document = await async_client.documents.upload(
            file="U3RhaW5sZXNzIHJvY2tz",
        )
        assert_matches_type(DocumentUploadResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_upload_with_all_params_overload_2(self, async_client: AsyncTelnyx) -> None:
        document = await async_client.documents.upload(
            file="U3RhaW5sZXNzIHJvY2tz",
            customer_reference="MY REF 001",
            filename="test-document.pdf",
        )
        assert_matches_type(DocumentUploadResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_upload_overload_2(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.documents.with_raw_response.upload(
            file="U3RhaW5sZXNzIHJvY2tz",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = await response.parse()
        assert_matches_type(DocumentUploadResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_upload_overload_2(self, async_client: AsyncTelnyx) -> None:
        async with async_client.documents.with_streaming_response.upload(
            file="U3RhaW5sZXNzIHJvY2tz",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = await response.parse()
            assert_matches_type(DocumentUploadResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_upload_json_overload_1(self, async_client: AsyncTelnyx) -> None:
        document = await async_client.documents.upload_json(
            url="https://www.w3.org/WAI/ER/tests/xhtml/testfiles/resources/pdf/dummy.pdf",
        )
        assert_matches_type(DocumentUploadJsonResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_upload_json_with_all_params_overload_1(self, async_client: AsyncTelnyx) -> None:
        document = await async_client.documents.upload_json(
            url="https://www.w3.org/WAI/ER/tests/xhtml/testfiles/resources/pdf/dummy.pdf",
            customer_reference="MY REF 001",
            filename="test-document.pdf",
        )
        assert_matches_type(DocumentUploadJsonResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_upload_json_overload_1(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.documents.with_raw_response.upload_json(
            url="https://www.w3.org/WAI/ER/tests/xhtml/testfiles/resources/pdf/dummy.pdf",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = await response.parse()
        assert_matches_type(DocumentUploadJsonResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_upload_json_overload_1(self, async_client: AsyncTelnyx) -> None:
        async with async_client.documents.with_streaming_response.upload_json(
            url="https://www.w3.org/WAI/ER/tests/xhtml/testfiles/resources/pdf/dummy.pdf",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = await response.parse()
            assert_matches_type(DocumentUploadJsonResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_upload_json_overload_2(self, async_client: AsyncTelnyx) -> None:
        document = await async_client.documents.upload_json(
            file="U3RhaW5sZXNzIHJvY2tz",
        )
        assert_matches_type(DocumentUploadJsonResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_upload_json_with_all_params_overload_2(self, async_client: AsyncTelnyx) -> None:
        document = await async_client.documents.upload_json(
            file="U3RhaW5sZXNzIHJvY2tz",
            customer_reference="MY REF 001",
            filename="test-document.pdf",
        )
        assert_matches_type(DocumentUploadJsonResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_upload_json_overload_2(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.documents.with_raw_response.upload_json(
            file="U3RhaW5sZXNzIHJvY2tz",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = await response.parse()
        assert_matches_type(DocumentUploadJsonResponse, document, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_upload_json_overload_2(self, async_client: AsyncTelnyx) -> None:
        async with async_client.documents.with_streaming_response.upload_json(
            file="U3RhaW5sZXNzIHJvY2tz",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = await response.parse()
            assert_matches_type(DocumentUploadJsonResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List

from ..._models import BaseModel
from ..task_status import TaskStatus

__all__ = ["ClusterRetrieveResponse", "Data"]


class Data(BaseModel):
    bucket: str

    clusters: List["RecursiveCluster"]

    status: TaskStatus


class ClusterRetrieveResponse(BaseModel):
    data: Data


from .recursive_cluster import RecursiveCluster



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from ...._models import BaseModel
from .assistant_test import AssistantTest
from .tests.test_suites.meta import Meta

__all__ = ["TestListResponse"]


class TestListResponse(BaseModel):
    __test__ = False
    data: List[AssistantTest]
    """Array of assistant test objects for the current page."""

    meta: Meta
    """Pagination metadata including total counts and current page info."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import private_wireless_gateway_list_params, private_wireless_gateway_create_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.private_wireless_gateway_list_response import PrivateWirelessGatewayListResponse
from ..types.private_wireless_gateway_create_response import PrivateWirelessGatewayCreateResponse
from ..types.private_wireless_gateway_delete_response import PrivateWirelessGatewayDeleteResponse
from ..types.private_wireless_gateway_retrieve_response import PrivateWirelessGatewayRetrieveResponse

__all__ = ["PrivateWirelessGatewaysResource", "AsyncPrivateWirelessGatewaysResource"]


class PrivateWirelessGatewaysResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> PrivateWirelessGatewaysResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return PrivateWirelessGatewaysResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PrivateWirelessGatewaysResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return PrivateWirelessGatewaysResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        name: str,
        network_id: str,
        region_code: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PrivateWirelessGatewayCreateResponse:
        """
        Asynchronously create a Private Wireless Gateway for SIM cards for a previously
        created network. This operation may take several minutes so you can check the
        Private Wireless Gateway status at the section Get a Private Wireless Gateway.

        Args:
          name: The private wireless gateway name.

          network_id: The identification of the related network resource.

          region_code: The code of the region where the private wireless gateway will be assigned. A
              list of available regions can be found at the regions endpoint

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/private_wireless_gateways",
            body=maybe_transform(
                {
                    "name": name,
                    "network_id": network_id,
                    "region_code": region_code,
                },
                private_wireless_gateway_create_params.PrivateWirelessGatewayCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PrivateWirelessGatewayCreateResponse,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PrivateWirelessGatewayRetrieveResponse:
        """
        Retrieve information about a Private Wireless Gateway.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/private_wireless_gateways/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PrivateWirelessGatewayRetrieveResponse,
        )

    def list(
        self,
        *,
        filter_created_at: str | Omit = omit,
        filter_ip_range: str | Omit = omit,
        filter_name: str | Omit = omit,
        filter_region_code: str | Omit = omit,
        filter_updated_at: str | Omit = omit,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PrivateWirelessGatewayListResponse:
        """
        Get all Private Wireless Gateways belonging to the user.

        Args:
          filter_created_at: Private Wireless Gateway resource creation date.

          filter_ip_range: The IP address range of the Private Wireless Gateway.

          filter_name: The name of the Private Wireless Gateway.

          filter_region_code: The name of the region where the Private Wireless Gateway is deployed.

          filter_updated_at: When the Private Wireless Gateway was last updated.

          page_number: The page number to load.

          page_size: The size of the page.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/private_wireless_gateways",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter_created_at": filter_created_at,
                        "filter_ip_range": filter_ip_range,
                        "filter_name": filter_name,
                        "filter_region_code": filter_region_code,
                        "filter_updated_at": filter_updated_at,
                        "page_number": page_number,
                        "page_size": page_size,
                    },
                    private_wireless_gateway_list_params.PrivateWirelessGatewayListParams,
                ),
            ),
            cast_to=PrivateWirelessGatewayListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PrivateWirelessGatewayDeleteResponse:
        """
        Deletes the Private Wireless Gateway.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._delete(
            f"/private_wireless_gateways/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PrivateWirelessGatewayDeleteResponse,
        )


class AsyncPrivateWirelessGatewaysResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncPrivateWirelessGatewaysResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPrivateWirelessGatewaysResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPrivateWirelessGatewaysResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncPrivateWirelessGatewaysResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        name: str,
        network_id: str,
        region_code: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PrivateWirelessGatewayCreateResponse:
        """
        Asynchronously create a Private Wireless Gateway for SIM cards for a previously
        created network. This operation may take several minutes so you can check the
        Private Wireless Gateway status at the section Get a Private Wireless Gateway.

        Args:
          name: The private wireless gateway name.

          network_id: The identification of the related network resource.

          region_code: The code of the region where the private wireless gateway will be assigned. A
              list of available regions can be found at the regions endpoint

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/private_wireless_gateways",
            body=await async_maybe_transform(
                {
                    "name": name,
                    "network_id": network_id,
                    "region_code": region_code,
                },
                private_wireless_gateway_create_params.PrivateWirelessGatewayCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PrivateWirelessGatewayCreateResponse,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PrivateWirelessGatewayRetrieveResponse:
        """
        Retrieve information about a Private Wireless Gateway.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/private_wireless_gateways/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PrivateWirelessGatewayRetrieveResponse,
        )

    async def list(
        self,
        *,
        filter_created_at: str | Omit = omit,
        filter_ip_range: str | Omit = omit,
        filter_name: str | Omit = omit,
        filter_region_code: str | Omit = omit,
        filter_updated_at: str | Omit = omit,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PrivateWirelessGatewayListResponse:
        """
        Get all Private Wireless Gateways belonging to the user.

        Args:
          filter_created_at: Private Wireless Gateway resource creation date.

          filter_ip_range: The IP address range of the Private Wireless Gateway.

          filter_name: The name of the Private Wireless Gateway.

          filter_region_code: The name of the region where the Private Wireless Gateway is deployed.

          filter_updated_at: When the Private Wireless Gateway was last updated.

          page_number: The page number to load.

          page_size: The size of the page.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/private_wireless_gateways",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "filter_created_at": filter_created_at,
                        "filter_ip_range": filter_ip_range,
                        "filter_name": filter_name,
                        "filter_region_code": filter_region_code,
                        "filter_updated_at": filter_updated_at,
                        "page_number": page_number,
                        "page_size": page_size,
                    },
                    private_wireless_gateway_list_params.PrivateWirelessGatewayListParams,
                ),
            ),
            cast_to=PrivateWirelessGatewayListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PrivateWirelessGatewayDeleteResponse:
        """
        Deletes the Private Wireless Gateway.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._delete(
            f"/private_wireless_gateways/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PrivateWirelessGatewayDeleteResponse,
        )


class PrivateWirelessGatewaysResourceWithRawResponse:
    def __init__(self, private_wireless_gateways: PrivateWirelessGatewaysResource) -> None:
        self._private_wireless_gateways = private_wireless_gateways

        self.create = to_raw_response_wrapper(
            private_wireless_gateways.create,
        )
        self.retrieve = to_raw_response_wrapper(
            private_wireless_gateways.retrieve,
        )
        self.list = to_raw_response_wrapper(
            private_wireless_gateways.list,
        )
        self.delete = to_raw_response_wrapper(
            private_wireless_gateways.delete,
        )


class AsyncPrivateWirelessGatewaysResourceWithRawResponse:
    def __init__(self, private_wireless_gateways: AsyncPrivateWirelessGatewaysResource) -> None:
        self._private_wireless_gateways = private_wireless_gateways

        self.create = async_to_raw_response_wrapper(
            private_wireless_gateways.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            private_wireless_gateways.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            private_wireless_gateways.list,
        )
        self.delete = async_to_raw_response_wrapper(
            private_wireless_gateways.delete,
        )


class PrivateWirelessGatewaysResourceWithStreamingResponse:
    def __init__(self, private_wireless_gateways: PrivateWirelessGatewaysResource) -> None:
        self._private_wireless_gateways = private_wireless_gateways

        self.create = to_streamed_response_wrapper(
            private_wireless_gateways.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            private_wireless_gateways.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            private_wireless_gateways.list,
        )
        self.delete = to_streamed_response_wrapper(
            private_wireless_gateways.delete,
        )


class AsyncPrivateWirelessGatewaysResourceWithStreamingResponse:
    def __init__(self, private_wireless_gateways: AsyncPrivateWirelessGatewaysResource) -> None:
        self._private_wireless_gateways = private_wireless_gateways

        self.create = async_to_streamed_response_wrapper(
            private_wireless_gateways.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            private_wireless_gateways.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            private_wireless_gateways.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            private_wireless_gateways.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["PartnerCampaignListSharedByMeResponse", "Record"]


class Record(BaseModel):
    brand_id: str = FieldInfo(alias="brandId")
    """Alphanumeric identifier of the brand associated with this campaign."""

    campaign_id: str = FieldInfo(alias="campaignId")
    """Alphanumeric identifier assigned by the registry for a campaign.

    This identifier is required by the NetNumber OSR SMS enabling process of 10DLC.
    """

    usecase: str
    """Campaign usecase.

    Must be of defined valid types. Use `/registry/enum/usecase` operation to
    retrieve usecases available for given brand.
    """

    create_date: Optional[str] = FieldInfo(alias="createDate", default=None)
    """Unix timestamp when campaign was created."""

    status: Optional[str] = None
    """Current campaign status.

    Possible values: ACTIVE, EXPIRED. A newly created campaign defaults to ACTIVE
    status.
    """


class PartnerCampaignListSharedByMeResponse(BaseModel):
    page: Optional[int] = None

    records: Optional[List[Record]] = None

    total_records: Optional[int] = FieldInfo(alias="totalRecords", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["DynamicEmergencyEndpointListParams", "Filter", "Page"]


class DynamicEmergencyEndpointListParams(TypedDict, total=False):
    filter: Filter
    """Consolidated filter parameter (deepObject style).

    Originally: filter[status], filter[country_code]
    """

    page: Page
    """Consolidated page parameter (deepObject style).

    Originally: page[size], page[number]
    """


class Filter(TypedDict, total=False):
    country_code: str
    """Filter by country code."""

    status: Literal["pending", "activated", "rejected"]
    """Filter by status."""


class Page(TypedDict, total=False):
    number: int
    """The page number to load"""

    size: int
    """The size of the page"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel

__all__ = ["AIRetrieveModelsResponse", "Data"]


class Data(BaseModel):
    id: str

    created: int

    owned_by: str

    object: Optional[str] = None


class AIRetrieveModelsResponse(BaseModel):
    data: List[Data]

    object: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Union, Optional
from typing_extensions import Literal, TypeAlias

from ..._models import BaseModel

__all__ = [
    "VoiceSettings",
    "BackgroundAudio",
    "BackgroundAudioUnionMember0",
    "BackgroundAudioUnionMember1",
    "BackgroundAudioUnionMember2",
]


class BackgroundAudioUnionMember0(BaseModel):
    type: Literal["predefined_media"]
    """Select from predefined media options."""

    value: Literal["silence", "office"]
    """The predefined media to use. `silence` disables background audio."""


class BackgroundAudioUnionMember1(BaseModel):
    type: Literal["media_url"]
    """Provide a direct URL to an MP3 file. The audio will loop during the call."""

    value: str
    """HTTPS URL to an MP3 file."""


class BackgroundAudioUnionMember2(BaseModel):
    type: Literal["media_name"]
    """Reference a previously uploaded media by its name from Telnyx Media Storage."""

    value: str
    """
    The `name` of a media asset created via
    [Media Storage API](https://developers.telnyx.com/api/media-storage/create-media-storage).
    The audio will loop during the call.
    """


BackgroundAudio: TypeAlias = Union[
    BackgroundAudioUnionMember0, BackgroundAudioUnionMember1, BackgroundAudioUnionMember2
]


class VoiceSettings(BaseModel):
    voice: str
    """The voice to be used by the voice assistant.

    Check the full list of
    [available voices](https://developers.telnyx.com/api/call-control/list-text-to-speech-voices)
    via our voices API. To use ElevenLabs, you must reference your ElevenLabs API
    key as an integration secret under the `api_key_ref` field. See
    [integration secrets documentation](https://developers.telnyx.com/api/secrets-manager/integration-secrets/create-integration-secret)
    for details. For Telnyx voices, use `Telnyx.<model_id>.<voice_id>` (e.g.
    Telnyx.KokoroTTS.af_heart)
    """

    api_key_ref: Optional[str] = None
    """
    The `identifier` for an integration secret
    [/v2/integration_secrets](https://developers.telnyx.com/api/secrets-manager/integration-secrets/create-integration-secret)
    that refers to your ElevenLabs API key. Warning: Free plans are unlikely to work
    with this integration.
    """

    background_audio: Optional[BackgroundAudio] = None
    """Optional background audio to play on the call.

    Use a predefined media bed, or supply a looped MP3 URL. If a media URL is chosen
    in the portal, customers can preview it before saving.
    """

    voice_speed: Optional[float] = None
    """The speed of the voice in the range [0.25, 2.0].

    1.0 is deafult speed. Larger numbers make the voice faster, smaller numbers make
    it slower. This is only applicable for Telnyx Natural voices.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .hangup_tool import HangupTool as HangupTool
from .conversation import Conversation as Conversation
from .webhook_tool import WebhookTool as WebhookTool
from .transfer_tool import TransferTool as TransferTool
from .assistant_tool import AssistantTool as AssistantTool
from .retrieval_tool import RetrievalTool as RetrievalTool
from .voice_settings import VoiceSettings as VoiceSettings
from .assistant_param import AssistantParam as AssistantParam
from .assistants_list import AssistantsList as AssistantsList
from .import_metadata import ImportMetadata as ImportMetadata
from .enabled_features import EnabledFeatures as EnabledFeatures
from .insight_settings import InsightSettings as InsightSettings
from .privacy_settings import PrivacySettings as PrivacySettings
from .hangup_tool_param import HangupToolParam as HangupToolParam
from .recursive_cluster import RecursiveCluster as RecursiveCluster
from .embedding_response import EmbeddingResponse as EmbeddingResponse
from .hangup_tool_params import HangupToolParams as HangupToolParams
from .messaging_settings import MessagingSettings as MessagingSettings
from .telephony_settings import TelephonySettings as TelephonySettings
from .webhook_tool_param import WebhookToolParam as WebhookToolParam
from .cluster_list_params import ClusterListParams as ClusterListParams
from .inference_embedding import InferenceEmbedding as InferenceEmbedding
from .transfer_tool_param import TransferToolParam as TransferToolParam
from .assistant_tool_param import AssistantToolParam as AssistantToolParam
from .embedding_url_params import EmbeddingURLParams as EmbeddingURLParams
from .retrieval_tool_param import RetrievalToolParam as RetrievalToolParam
from .voice_settings_param import VoiceSettingsParam as VoiceSettingsParam
from .assistant_chat_params import AssistantChatParams as AssistantChatParams
from .cluster_list_response import ClusterListResponse as ClusterListResponse
from .embedding_list_params import EmbeddingListParams as EmbeddingListParams
from .background_task_status import BackgroundTaskStatus as BackgroundTaskStatus
from .cluster_compute_params import ClusterComputeParams as ClusterComputeParams
from .insight_settings_param import InsightSettingsParam as InsightSettingsParam
from .privacy_settings_param import PrivacySettingsParam as PrivacySettingsParam
from .transcription_settings import TranscriptionSettings as TranscriptionSettings
from .assistant_chat_response import AssistantChatResponse as AssistantChatResponse
from .assistant_create_params import AssistantCreateParams as AssistantCreateParams
from .assistant_import_params import AssistantImportParams as AssistantImportParams
from .assistant_update_params import AssistantUpdateParams as AssistantUpdateParams
from .audio_transcribe_params import AudioTranscribeParams as AudioTranscribeParams
from .cluster_retrieve_params import ClusterRetrieveParams as ClusterRetrieveParams
from .embedding_create_params import EmbeddingCreateParams as EmbeddingCreateParams
from .embedding_list_response import EmbeddingListResponse as EmbeddingListResponse
from .cluster_compute_response import ClusterComputeResponse as ClusterComputeResponse
from .conversation_list_params import ConversationListParams as ConversationListParams
from .hangup_tool_params_param import HangupToolParamsParam as HangupToolParamsParam
from .messaging_settings_param import MessagingSettingsParam as MessagingSettingsParam
from .telephony_settings_param import TelephonySettingsParam as TelephonySettingsParam
from .assistant_delete_response import AssistantDeleteResponse as AssistantDeleteResponse
from .assistant_retrieve_params import AssistantRetrieveParams as AssistantRetrieveParams
from .audio_transcribe_response import AudioTranscribeResponse as AudioTranscribeResponse
from .cluster_retrieve_response import ClusterRetrieveResponse as ClusterRetrieveResponse
from .cluster_fetch_graph_params import ClusterFetchGraphParams as ClusterFetchGraphParams
from .conversation_create_params import ConversationCreateParams as ConversationCreateParams
from .conversation_list_response import ConversationListResponse as ConversationListResponse
from .conversation_update_params import ConversationUpdateParams as ConversationUpdateParams
from .embedding_retrieve_response import EmbeddingRetrieveResponse as EmbeddingRetrieveResponse
from .assistant_get_texml_response import AssistantGetTexmlResponse as AssistantGetTexmlResponse
from .conversation_update_response import ConversationUpdateResponse as ConversationUpdateResponse
from .transcription_settings_param import TranscriptionSettingsParam as TranscriptionSettingsParam
from .chat_create_completion_params import ChatCreateCompletionParams as ChatCreateCompletionParams
from .conversation_retrieve_response import ConversationRetrieveResponse as ConversationRetrieveResponse
from .inference_embedding_bucket_ids import InferenceEmbeddingBucketIDs as InferenceEmbeddingBucketIDs
from .conversation_add_message_params import ConversationAddMessageParams as ConversationAddMessageParams
from .embedding_similarity_search_params import EmbeddingSimilaritySearchParams as EmbeddingSimilaritySearchParams
from .embedding_similarity_search_response import EmbeddingSimilaritySearchResponse as EmbeddingSimilaritySearchResponse
from .inference_embedding_bucket_ids_param import InferenceEmbeddingBucketIDsParam as InferenceEmbeddingBucketIDsParam
from .inference_embedding_webhook_tool_params import (
    InferenceEmbeddingWebhookToolParams as InferenceEmbeddingWebhookToolParams,
)
from .inference_embedding_transfer_tool_params import (
    InferenceEmbeddingTransferToolParams as InferenceEmbeddingTransferToolParams,
)
from .inference_embedding_webhook_tool_params_param import (
    InferenceEmbeddingWebhookToolParamsParam as InferenceEmbeddingWebhookToolParamsParam,
)
from .inference_embedding_transfer_tool_params_param import (
    InferenceEmbeddingTransferToolParamsParam as InferenceEmbeddingTransferToolParamsParam,
)
from .conversation_retrieve_conversations_insights_response import (
    ConversationRetrieveConversationsInsightsResponse as ConversationRetrieveConversationsInsightsResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["CampaignGetMnoMetadataResponse", "_10999"]


class _10999(BaseModel):
    min_msg_samples: int = FieldInfo(alias="minMsgSamples")

    mno: str

    mno_review: bool = FieldInfo(alias="mnoReview")

    mno_support: bool = FieldInfo(alias="mnoSupport")

    no_embedded_link: bool = FieldInfo(alias="noEmbeddedLink")

    no_embedded_phone: bool = FieldInfo(alias="noEmbeddedPhone")

    qualify: bool

    req_subscriber_help: bool = FieldInfo(alias="reqSubscriberHelp")

    req_subscriber_optin: bool = FieldInfo(alias="reqSubscriberOptin")

    req_subscriber_optout: bool = FieldInfo(alias="reqSubscriberOptout")


class CampaignGetMnoMetadataResponse(BaseModel):
    api_10999: Optional[_10999] = FieldInfo(alias="10999", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ChannelZoneListParams", "Page"]


class ChannelZoneListParams(TypedDict, total=False):
    page: Page
    """Consolidated page parameter (deepObject style).

    Originally: page[size], page[number]
    """


class Page(TypedDict, total=False):
    number: int
    """The page number to load"""

    size: int
    """The size of the page"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["InterruptionSettingsParam"]


class InterruptionSettingsParam(TypedDict, total=False):
    enable: bool
    """When true, allows users to interrupt the assistant while speaking"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, TypedDict

from ..sip_header_param import SipHeaderParam
from ..custom_sip_header_param import CustomSipHeaderParam

__all__ = ["ActionReferParams"]


class ActionReferParams(TypedDict, total=False):
    sip_address: Required[str]
    """The SIP URI to which the call will be referred to."""

    client_state: str
    """Use this field to add state to every subsequent webhook.

    It must be a valid Base-64 encoded string.
    """

    command_id: str
    """Use this field to avoid execution of duplicate commands.

    Telnyx will ignore subsequent commands with the same `command_id` as one that
    has already been executed.
    """

    custom_headers: Iterable[CustomSipHeaderParam]
    """Custom headers to be added to the SIP INVITE."""

    sip_auth_password: str
    """SIP Authentication password used for SIP challenges."""

    sip_auth_username: str
    """SIP Authentication username used for SIP challenges."""

    sip_headers: Iterable[SipHeaderParam]
    """SIP headers to be added to the request.

    Currently only User-to-User header is supported.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

from .._types import SequenceNotStr

__all__ = ["CredentialInboundParam"]


class CredentialInboundParam(TypedDict, total=False):
    ani_number_format: Literal["+E.164", "E.164", "+E.164-national", "E.164-national"]
    """
    This setting allows you to set the format with which the caller's number (ANI)
    is sent for inbound phone calls.
    """

    channel_limit: int
    """
    When set, this will limit the total number of inbound calls to phone numbers
    associated with this connection.
    """

    codecs: SequenceNotStr[str]
    """
    Defines the list of codecs that Telnyx will send for inbound calls to a specific
    number on your portal account, in priority order. This only works when the
    Connection the number is assigned to uses Media Handling mode: default. OPUS and
    H.264 codecs are available only when using TCP or TLS transport for SIP.
    """

    dnis_number_format: Literal["+e164", "e164", "national", "sip_username"]

    generate_ringback_tone: bool
    """Generate ringback tone through 183 session progress message with early media."""

    isup_headers_enabled: bool
    """When set, inbound phone calls will receive ISUP parameters via SIP headers.

    (Only when available and only when using TCP or TLS transport.)
    """

    prack_enabled: bool
    """Enable PRACK messages as defined in RFC3262."""

    shaken_stir_enabled: bool
    """
    When enabled the SIP Connection will receive the Identity header with
    Shaken/Stir data in the SIP INVITE message of inbound calls, even when using UDP
    transport.
    """

    sip_compact_headers_enabled: bool
    """Defaults to true."""

    timeout_1xx_secs: int
    """Time(sec) before aborting if connection is not made."""

    timeout_2xx_secs: int
    """Time(sec) before aborting if call is unanswered (min: 1, max: 600)."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .record_param import RecordParam

__all__ = ["GlobalIPAssignmentParam"]


class GlobalIPAssignmentParam(RecordParam, total=False):
    global_ip_id: str
    """Global IP ID."""

    is_in_maintenance: bool
    """Enable/disable BGP announcement."""

    wireguard_peer_id: str
    """Wireguard peer ID."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .action_verify_params import ActionVerifyParams as ActionVerifyParams
from .verify_verification_code_response import VerifyVerificationCodeResponse as VerifyVerificationCodeResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["PhoneNumbersRegulatoryRequirementRetrieveParams", "Filter"]


class PhoneNumbersRegulatoryRequirementRetrieveParams(TypedDict, total=False):
    filter: Filter
    """Consolidated filter parameter (deepObject style).

    Originally: filter[phone_number]
    """


class Filter(TypedDict, total=False):
    phone_number: str
    """Record type phone number/ phone numbers"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["SimCardGroupCreateParams", "DataLimit"]


class SimCardGroupCreateParams(TypedDict, total=False):
    name: Required[str]
    """A user friendly name for the SIM card group."""

    data_limit: DataLimit
    """Upper limit on the amount of data the SIM cards, within the group, can use."""


class DataLimit(TypedDict, total=False):
    amount: str

    unit: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional

from ..._models import BaseModel

__all__ = ["EmbeddingSimilaritySearchResponse", "Data", "DataMetadata"]


class DataMetadata(BaseModel):
    checksum: str

    embedding: str

    filename: str

    source: str

    certainty: Optional[float] = None

    loader_metadata: Optional[Dict[str, object]] = None


class Data(BaseModel):
    distance: float

    document_chunk: str

    metadata: DataMetadata


class EmbeddingSimilaritySearchResponse(BaseModel):
    data: List[Data]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Any, cast
from typing_extensions import Literal

import httpx

from .._types import Body, Query, Headers, NotGiven, not_given
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.enum_retrieve_response import EnumRetrieveResponse

__all__ = ["EnumResource", "AsyncEnumResource"]


class EnumResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> EnumResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return EnumResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> EnumResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return EnumResourceWithStreamingResponse(self)

    def retrieve(
        self,
        endpoint: Literal[
            "mno",
            "optionalAttributes",
            "usecase",
            "vertical",
            "altBusinessIdType",
            "brandIdentityStatus",
            "brandRelationship",
            "campaignStatus",
            "entityType",
            "extVettingProvider",
            "vettingStatus",
            "brandStatus",
            "operationStatus",
            "approvedPublicCompany",
            "stockExchange",
            "vettingClass",
        ],
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EnumRetrieveResponse:
        """
        Get Enum

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not endpoint:
            raise ValueError(f"Expected a non-empty value for `endpoint` but received {endpoint!r}")
        return cast(
            EnumRetrieveResponse,
            self._get(
                f"/enum/{endpoint}",
                options=make_request_options(
                    extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
                ),
                cast_to=cast(
                    Any, EnumRetrieveResponse
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )


class AsyncEnumResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncEnumResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncEnumResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncEnumResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncEnumResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        endpoint: Literal[
            "mno",
            "optionalAttributes",
            "usecase",
            "vertical",
            "altBusinessIdType",
            "brandIdentityStatus",
            "brandRelationship",
            "campaignStatus",
            "entityType",
            "extVettingProvider",
            "vettingStatus",
            "brandStatus",
            "operationStatus",
            "approvedPublicCompany",
            "stockExchange",
            "vettingClass",
        ],
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EnumRetrieveResponse:
        """
        Get Enum

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not endpoint:
            raise ValueError(f"Expected a non-empty value for `endpoint` but received {endpoint!r}")
        return cast(
            EnumRetrieveResponse,
            await self._get(
                f"/enum/{endpoint}",
                options=make_request_options(
                    extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
                ),
                cast_to=cast(
                    Any, EnumRetrieveResponse
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )


class EnumResourceWithRawResponse:
    def __init__(self, enum: EnumResource) -> None:
        self._enum = enum

        self.retrieve = to_raw_response_wrapper(
            enum.retrieve,
        )


class AsyncEnumResourceWithRawResponse:
    def __init__(self, enum: AsyncEnumResource) -> None:
        self._enum = enum

        self.retrieve = async_to_raw_response_wrapper(
            enum.retrieve,
        )


class EnumResourceWithStreamingResponse:
    def __init__(self, enum: EnumResource) -> None:
        self._enum = enum

        self.retrieve = to_streamed_response_wrapper(
            enum.retrieve,
        )


class AsyncEnumResourceWithStreamingResponse:
    def __init__(self, enum: AsyncEnumResource) -> None:
        self._enum = enum

        self.retrieve = async_to_streamed_response_wrapper(
            enum.retrieve,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["PortingOrdersExceptionType"]


class PortingOrdersExceptionType(BaseModel):
    code: Optional[
        Literal[
            "ACCOUNT_NUMBER_MISMATCH",
            "AUTH_PERSON_MISMATCH",
            "BTN_ATN_MISMATCH",
            "ENTITY_NAME_MISMATCH",
            "FOC_EXPIRED",
            "FOC_REJECTED",
            "LOCATION_MISMATCH",
            "LSR_PENDING",
            "MAIN_BTN_PORTING",
            "OSP_IRRESPONSIVE",
            "OTHER",
            "PASSCODE_PIN_INVALID",
            "PHONE_NUMBER_HAS_SPECIAL_FEATURE",
            "PHONE_NUMBER_MISMATCH",
            "PHONE_NUMBER_NOT_PORTABLE",
            "PORT_TYPE_INCORRECT",
            "PORTING_ORDER_SPLIT_REQUIRED",
            "POSTAL_CODE_MISMATCH",
            "RATE_CENTER_NOT_PORTABLE",
            "SV_CONFLICT",
            "SV_UNKNOWN_FAILURE",
        ]
    ] = None
    """Identifier of an exception type"""

    description: Optional[str] = None
    """Description of an exception type"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel
from .fqdn_connection import FqdnConnection
from .shared.connections_pagination_meta import ConnectionsPaginationMeta

__all__ = ["FqdnConnectionListResponse"]


class FqdnConnectionListResponse(BaseModel):
    data: Optional[List[FqdnConnection]] = None

    meta: Optional[ConnectionsPaginationMeta] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel
from .credential_connection import CredentialConnection
from .shared.connections_pagination_meta import ConnectionsPaginationMeta

__all__ = ["CredentialConnectionListResponse"]


class CredentialConnectionListResponse(BaseModel):
    data: Optional[List[CredentialConnection]] = None

    meta: Optional[ConnectionsPaginationMeta] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .shared.short_code import ShortCode

__all__ = ["ShortCodeRetrieveResponse"]


class ShortCodeRetrieveResponse(BaseModel):
    data: Optional[ShortCode] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal

from ..._models import BaseModel
from .inference_embedding_transfer_tool_params import InferenceEmbeddingTransferToolParams

__all__ = ["TransferTool"]


class TransferTool(BaseModel):
    transfer: InferenceEmbeddingTransferToolParams

    type: Literal["transfer"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel
from .porting_phone_number_block import PortingPhoneNumberBlock

__all__ = ["PhoneNumberBlockCreateResponse"]


class PhoneNumberBlockCreateResponse(BaseModel):
    data: Optional[PortingPhoneNumberBlock] = None
